<?php if ( ! defined('BASEPATH')) exit('No direct script access allowed');

class Contacto extends GS_Controller {
    
    public function __construct()    {
        parent::__construct();
        $this->lang->load('contacto', $this->language);
        $this->load->model('siteconfig');
        $this->load->library('email');
        $this->load->helper('form');
        $this->load->library('form_validation');
    }
    
    public function index() {
 
        $this->gs_data['landing'] = TRUE;
        
        $this->go_main();
    }
    
    private function go_main() {
        $this->gs_data['state'] = $this->create_state($this);
        $this->gs_data['add1'] = $this->siteconfig->config_value('CONTACT_ADD1')->value_str;
        $this->gs_data['add2'] = $this->siteconfig->config_value('CONTACT_ADD2')->value_str;
        $this->gs_data['mailto'] = $this->siteconfig->config_value('CONTACT_EMAIL')->value_str;
        
        $css      = $this->extra_css();
        $js       = $this->extra_js();
        $html     = $this->load->view('contacto/main', $this->gs_data, true);
        $this->forward($html, $css, $js);
    }
    
    public function send() {
        $name    = $this->input->post('nombre', TRUE);
        $email   = $this->input->post('email', TRUE);
        $tel     = $this->input->post('tel', TRUE);
        $coments = $this->input->post('comments', TRUE);
        $this->gs_data['landing'] = FALSE;
        
        $this->set_validation_rules();
        
        
        if ($this->form_validation->run() == FALSE) {
            $this->gs_data['form_bad'] = lang('contacto.ui.validation.formerrors');
            $this->gs_data['form_good'] = "";
        } else {
            $this->gs_data['form_good'] = lang('contacto.ui.validation.formgood');
            $this->gs_data['form_bad'] = "";
        }
        $this->create_and_send($name, $email, $tel, $coments);
    }
    
    private function create_and_send($name, $email, $tel, $coments) {
        log_message('debug', "data: $name, $email, $tel, $coments");
        $this->email->from($email, $name);
        $this->email->to($this->contact_email());
        $this->email->bcc($this->email_bcc()); 

        $this->email->subject($this->email_subject());
        $this->email->message($coments);

        $this->email->send();

        log_message('debug', $this->email->print_debugger());
        $this->go_main();
    }
    
    private function set_validation_rules() {
        $this->form_validation
             ->set_rules('nombre', 
             lang('contacto.ui.nombre'), 'ctype_alpha|required');
        $this->form_validation
             ->set_rules('email', 
             lang('contacto.ui.correo'), 'required|valid_email');
        $this->form_validation
             ->set_rules('tel',  
             lang('contacto.ui.tel'), 'required');
        $this->form_validation
             ->set_rules('comments',  
             lang('contacto.ui.comentarios'), 'required');
             
        $this->form_validation->set_message('required', 
            html_escape(lang('contacto.ui.validation.required')));
        $this->form_validation->set_message('valid_email', 
            html_escape(lang('contacto.ui.validation.email')));
    }
    
    public function name_check($name) {
        if (ctype_alpha($name)) {
            log_message('debug', 'is good name');
            return TRUE;
        } else {
            $this->form_validation
                 ->set_message('name_check',
                     html_escape(lang('contacto.ui.validation.name')));
            return FALSE;
        }
    }
        
        
    private function contact_email() {
        $email = $this->siteconfig
                      ->config_value('CONTACT_EMAIL')
                      ->value_str;
        log_message('debug', "contacto email:" . $email);
        return $email;
    }
    
    private function email_subject() {
        $subject = $this->siteconfig
                      ->config_value('CONTACT_EMAIL_SUBJECT')
                      ->value_str;
        log_message('debug', "contacto subject:" . $subject);
        return $subject;
    }
    
    private function email_bcc() {
        $bcc = $this->siteconfig
                      ->config_value('COMTACT_EMAIL_BCC')
                      ->value_str;
        log_message('debug', "contacto bcc:" . $bcc);
        return $bcc;
    }
    
    private function extra_css() {
        $css = link_tag('assets/css/contacto.css');;
        
        return $css;
    }

    private function extra_js() {
        $url = base_url("assets/js/contacto.js");
        $tag = '<script type="text/javascript" src="' . 
            html_escape($url) . '" ></script>';
        return $tag;
    }

    private function create_state() {
        return array(
            'active_button' => '',
            'language' => $this->language
        );
    }
    
}
